@@ -60,6 +60,7 @@ typedef struct {
 
 	GtkWidget *minimum_size_spin;
 	GtkWidget *maximum_size_spin;
+	GtkWidget *about;
 
 	/* gconf listeners id */
 	guint listeners [5];
@@ -97,20 +98,10 @@ static void
 response_cb(GtkWidget * widget,int id, TasklistData *tasklist)
 {
 	if(id == GTK_RESPONSE_HELP) {
-
 		GError *error = NULL;
-		static GnomeProgram *applet_program = NULL;
-
-		if (!applet_program) {
-			int argc = 1;
-			char *argv[2] = { "window-list" };
-			applet_program = gnome_program_init ("window-list", VERSION,
-							     LIBGNOME_MODULE,argc, argv,
-							     GNOME_PROGRAM_STANDARD_PROPERTIES,NULL);
-		}
 
 		egg_help_display_desktop_on_screen (
-			applet_program, "window-list",
+			NULL, "window-list",
 			"window-list", "windowlist-prefs",
 			gtk_widget_get_screen (tasklist->applet),
 			&error);
@@ -263,6 +254,15 @@ destroy_tasklist(GtkWidget * widget, TasklistData *tasklist)
 	tasklist->listeners[3] = 0;
 	tasklist->listeners[4] = 0;
 
+	if (tasklist->properties_dialog)
+		gtk_widget_destroy (tasklist->properties_dialog);
+
+	if (tasklist->about)
+		gtk_widget_destroy (tasklist->about);
+
+	if (tasklist->properties_dialog)
+		gtk_widget_destroy (tasklist->properties_dialog);
+
         g_free (tasklist);
 }
 
@@ -738,18 +738,9 @@ display_help_dialog (BonoboUIComponent *uic,
 		     const gchar       *verbname)
 {
 	GError *error = NULL;
-	static GnomeProgram *applet_program = NULL;
-
-	if (!applet_program) {
-		int argc = 1;
-		char *argv[2] = { "window-list" };
-		applet_program = gnome_program_init ("window-list", VERSION,
-						     LIBGNOME_MODULE,argc, argv,
-						     GNOME_PROGRAM_STANDARD_PROPERTIES,NULL);
-	}
 
 	egg_help_display_desktop_on_screen (
-			applet_program, "window-list",
+			NULL, "window-list",
 			"window-list", NULL,
 			gtk_widget_get_screen (tasklist->applet),
 			&error);
@@ -779,7 +770,6 @@ display_about_dialog (BonoboUIComponent *uic,
 		      TasklistData      *tasklist,
 		      const gchar       *verbname)
 {
-	static GtkWidget *about = NULL;
 	GdkPixbuf *pixbuf = NULL;
 	gchar *file;
 	
@@ -793,11 +783,11 @@ display_about_dialog (BonoboUIComponent *uic,
 	};
 	const char *translator_credits = _("translator_credits");
 
-	if (about) {
-		gtk_window_set_screen (GTK_WINDOW (about),
+	if (tasklist->about) {
+		gtk_window_set_screen (GTK_WINDOW (tasklist->about),
 				       gtk_widget_get_screen (tasklist->applet));
-		gtk_widget_show (about);
-		gtk_window_present (GTK_WINDOW (about));
+		gtk_widget_show (tasklist->about);
+		gtk_window_present (GTK_WINDOW (tasklist->about));
 		return;
 	}
 
@@ -805,7 +795,7 @@ display_about_dialog (BonoboUIComponent *uic,
 	pixbuf = gdk_pixbuf_new_from_file (file, NULL);
 	g_free(file);
 
-	about = gnome_about_new (_("Window List"), VERSION,
+	tasklist->about = gnome_about_new (_("Window List"), VERSION,
 				 "Copyright \xc2\xa9 2001-2002 Red Hat, Inc.",
 				 _("The Window List shows a list of all visible windows and lets you browse them."),
 				 authors,
@@ -813,19 +803,19 @@ display_about_dialog (BonoboUIComponent *uic,
 				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				 pixbuf);
 	
-	gtk_window_set_wmclass (GTK_WINDOW (about), "tasklist", "Tasklist");
-	gtk_window_set_screen (GTK_WINDOW (about),
+	gtk_window_set_wmclass (GTK_WINDOW (tasklist->about), "tasklist", "Tasklist");
+	gtk_window_set_screen (GTK_WINDOW (tasklist->about),
 			       gtk_widget_get_screen (tasklist->applet));
 
 	if (pixbuf) {
-		gtk_window_set_icon (GTK_WINDOW (about), pixbuf);
+		gtk_window_set_icon (GTK_WINDOW (tasklist->about), pixbuf);
 		g_object_unref (pixbuf);
 	}
 	
-	g_signal_connect (G_OBJECT(about), "destroy",
-			  (GCallback)gtk_widget_destroyed, &about);
+	g_signal_connect (G_OBJECT(tasklist->about), "destroy",
+			  (GCallback)gtk_widget_destroyed, &tasklist->about);
 	
-	gtk_widget_show (about);
+	gtk_widget_show (tasklist->about);
 }
 
 static void
