@@ -70,6 +70,8 @@ struct _PanelWidget
 	
 	GList          *applet_list;
 
+	GSList         *create_launcher_dialog_list;	
+
 	int             size;
 	GtkOrientation  orient;
 	int             sz;
@@ -88,6 +90,8 @@ struct _PanelWidget
 	                                  */
 	
 	GtkWidget      *panel_parent;
+
+	GtkWidget      *delete_dialog;
 	
 	GdkEventKey    *key_event;
 
@@ -122,12 +126,12 @@ struct _PanelWidgetClass
 
 GType		panel_widget_get_type		(void) G_GNUC_CONST;
 
-GtkWidget *	panel_widget_new		(gchar *panel_id,
+GtkWidget *	panel_widget_new		(const char *panel_id,
 						 gboolean packed,
 						 GtkOrientation orient,
 						 int sz,
 						 PanelBackgroundType back_type,
-						 char *back_pixmap,
+						 const char *back_pixmap,
 						 gboolean fit_pixmap_bg,
 						 gboolean stretch_pixmap_bg,
 						 gboolean rotate_pixmap_bg,
@@ -176,7 +180,7 @@ void		panel_widget_change_params	(PanelWidget *panel,
 						 GtkOrientation orient,
 						 int sz,
 						 PanelBackgroundType back_type,
-						 char *pixmap_name,
+						 const char *pixmap_name,
 						 gboolean fit_pixmap_bg,
 						 gboolean stretch_pixmap_bg,
 						 gboolean rotate_pixmap_bg,
@@ -209,6 +213,8 @@ void            panel_widget_focus              (PanelWidget *panel);
 
 PanelOrient     panel_widget_get_applet_orient  (PanelWidget *panel);
 
+void         panel_widget_remove_drawers (PanelWidget *panel_widget);
+
 extern gboolean panel_applet_in_drag;
 
 G_END_DECLS
